#mypackage
This is a simple exmaple package.
##Installation
You can install the package using pip:
```bash
pip install mypackage
```

## usage
from mypackage.mymodule import hello_world
print(hello_world())
